/soc/2013/ankitkv/gobjectification: a243a5e7afb3: Merge gtkdoc-c...

Ankit Vani a at nevitus.org
Sun Feb 9 13:47:20 EST 2014


Changeset: a243a5e7afb31658f5c5b3f4d3d0efaaf9503bc9
Author:	 Ankit Vani <a at nevitus.org>
Date:	 2014-02-10 00:16 +0530
Branch:	 soc.2013.gobjectification.plugins
URL: https://hg.pidgin.im/soc/2013/ankitkv/gobjectification/rev/a243a5e7afb3

Description:

Merge gtkdoc-conversion

diffstat:

 finch/gntblist.h           |   8 +++++---
 finch/gntlog.h             |   2 +-
 finch/gntpounce.h          |   6 +++---
 finch/gntrequest.h         |   2 +-
 finch/gntsound.h           |   5 +++--
 finch/gntui.h              |   2 +-
 finch/libgnt/gnt.h         |   5 +++--
 finch/libgnt/gntbindable.h |  12 ++++++------
 finch/libgnt/gntcombobox.h |   2 +-
 finch/libgnt/gntfilesel.h  |   5 +++--
 finch/libgnt/gntmenu.h     |   2 +-
 finch/libgnt/gntmenuitem.h |   8 ++++----
 finch/libgnt/gntstyle.h    |  11 ++++++-----
 finch/libgnt/gnttree.h     |  46 +++++++++++++++++++++++++++-------------------
 finch/libgnt/gntutils.h    |  19 ++++++++++---------
 finch/libgnt/gntwm.h       |   6 +++---
 pidgin/Makefile.mingw      |   2 +-
 17 files changed, 79 insertions(+), 64 deletions(-)

diffs (truncated from 436 to 300 lines):

diff --git a/finch/gntblist.h b/finch/gntblist.h
--- a/finch/gntblist.h
+++ b/finch/gntblist.h
@@ -136,12 +136,13 @@ void finch_blist_set_size(int width, int
 
 /**
  * finch_retrieve_user_info:
- * @conn:   The connection to get information fro
+ * @conn:   The connection to get information from
  * @name:   The user to get information about.
  *
  * Get information about a user. Show immediate feedback.
  *
- * Returns:  Returns the ui-handle for the userinfo notification.
+ * Returns: (transfer none): Returns the ui-handle for the userinfo
+ *          notification.
  */
 gpointer finch_retrieve_user_info(PurpleConnection *conn, const char *name);
 
@@ -149,7 +150,8 @@ gpointer finch_retrieve_user_info(Purple
  * finch_blist_get_tree:
  *
  * Get the tree list of the buddy list.
- * Returns:  The GntTree widget.
+ *
+ * Returns: (transfer none): The GntTree widget.
  */
 GntTree * finch_blist_get_tree(void);
 
diff --git a/finch/gntlog.h b/finch/gntlog.h
--- a/finch/gntlog.h
+++ b/finch/gntlog.h
@@ -81,7 +81,7 @@ void finch_log_init(void);
  *
  * Returns the GNT log subsystem handle.
  *
- * Returns: The GNT log subsystem handle.
+ * Returns: (transfer none): The GNT log subsystem handle.
  */
 void *finch_log_get_handle(void);
 
diff --git a/finch/gntpounce.h b/finch/gntpounce.h
--- a/finch/gntpounce.h
+++ b/finch/gntpounce.h
@@ -58,9 +58,9 @@ void finch_pounces_manager_hide(void);
 /**
  * finch_pounces_get_handle:
  *
- * Returns the gtkpounces handle
+ * Returns the GNT pounces handle
  *
- * Returns: The handle to the GTK+ pounces system
+ * Returns: (transfer none): The handle to the GNT pounces system
  */
 void *finch_pounces_get_handle(void);
 
@@ -78,4 +78,4 @@ void finch_pounces_init(void);
  */
 void finch_pounces_uninit(void);
 
-#endif /* _PURPLE_GTKPOUNCE_H_ */
+#endif /* _PURPLE_FINCHPOUNCE_H_ */
diff --git a/finch/gntrequest.h b/finch/gntrequest.h
--- a/finch/gntrequest.h
+++ b/finch/gntrequest.h
@@ -72,7 +72,7 @@ void finch_request_save_in_prefs(gpointe
  *
  * Create a widget field for a request-field.
  *
- * Returns: A GntWidget for the request field.
+ * Returns: (transfer full): A GntWidget for the request field.
  */
 GntWidget *finch_request_field_get_widget(PurpleRequestField *field);
 
diff --git a/finch/gntsound.h b/finch/gntsound.h
--- a/finch/gntsound.h
+++ b/finch/gntsound.h
@@ -56,8 +56,9 @@ void finch_sound_set_active_profile(cons
  *
  * Get a list of available sound profiles.
  *
- * Returns: A list of strings denoting sound profile names.
- *         Caller must free the list (but not the data).
+ * Returns: (transfer container) (element-type utf8): A list of strings
+ *          denoting sound profile names. Caller must free the list
+ *          (but not the data).
  */
 GList *finch_sound_get_profiles(void);
 
diff --git a/finch/gntui.h b/finch/gntui.h
--- a/finch/gntui.h
+++ b/finch/gntui.h
@@ -1,4 +1,4 @@
-/**
+/*
  * finch
  *
  * Finch is the legal property of its developers, whose names are too numerous
diff --git a/finch/libgnt/gnt.h b/finch/libgnt/gnt.h
--- a/finch/libgnt/gnt.h
+++ b/finch/libgnt/gnt.h
@@ -171,7 +171,7 @@ void gnt_quit(void);
  *
  * Get the global clipboard.
  *
- * Returns:  The clipboard.
+ * Returns: (transfer none): The clipboard.
  */
 GntClipboard * gnt_get_clipboard(void);
 
@@ -180,7 +180,8 @@ GntClipboard * gnt_get_clipboard(void);
  *
  * Get the string in the clipboard.
  *
- * Returns: A copy of the string in the clipboard. The caller must g_free() the string.
+ * Returns: A copy of the string in the clipboard. The caller
+ *          must g_free() the string.
  */
 gchar * gnt_get_clipboard_string(void);
 
diff --git a/finch/libgnt/gntbindable.h b/finch/libgnt/gntbindable.h
--- a/finch/libgnt/gntbindable.h
+++ b/finch/libgnt/gntbindable.h
@@ -120,11 +120,11 @@ void gnt_bindable_action_param_free(GntB
 
 /**
  * gnt_bindable_class_register_action:
- * @klass:      The class the binding is for.
- * @name:       The name of the binding.
- * @callback:   The callback  for the binding.
- * @trigger:    The default trigger for the binding, or %NULL, followed by a NULL-terminated
- *                   list of default parameters.
+ * @klass:    The class the binding is for.
+ * @name:     The name of the binding.
+ * @callback: (scope call): The callback for the binding.
+ * @trigger:  The default trigger for the binding, or %NULL, followed by a
+ *            %NULL-terminated list of default parameters.
  *
  * Register a bindable action for a class.
  */
@@ -179,7 +179,7 @@ gboolean gnt_bindable_perform_action_nam
  *
  * Returns a GntTree populated with "key" -> "binding" for the widget.
  *
- * Returns:   The GntTree.
+ * Returns: (transfer full): The GntTree.
  */
 GntBindable * gnt_bindable_bindings_view(GntBindable *bind);
 
diff --git a/finch/libgnt/gntcombobox.h b/finch/libgnt/gntcombobox.h
--- a/finch/libgnt/gntcombobox.h
+++ b/finch/libgnt/gntcombobox.h
@@ -120,7 +120,7 @@ void gnt_combo_box_remove_all(GntComboBo
  *
  * Get the data that is currently selected
  *
- * Returns: The data of the currently selected entry
+ * Returns: (transfer none): The data of the currently selected entry
  */
 gpointer gnt_combo_box_get_selected_data(GntComboBox *box);
 
diff --git a/finch/libgnt/gntfilesel.h b/finch/libgnt/gntfilesel.h
--- a/finch/libgnt/gntfilesel.h
+++ b/finch/libgnt/gntfilesel.h
@@ -185,8 +185,9 @@ char * gnt_file_sel_get_selected_file(Gn
  *
  * Get the list of selected files in the selector.
  *
- * Returns:  A list of paths for the selected files. The caller must g_free the
- *          contents of the list, and g_list_free the list.
+ * Returns: (transfer full) (element-type filename): A list of paths for the
+ *          selected files. The caller must g_free() the contents of the list,
+ *          and g_list_free() the list.
  */
 GList * gnt_file_sel_get_selected_multi_files(GntFileSel *sel);
 
diff --git a/finch/libgnt/gntmenu.h b/finch/libgnt/gntmenu.h
--- a/finch/libgnt/gntmenu.h
+++ b/finch/libgnt/gntmenu.h
@@ -125,7 +125,7 @@ void gnt_menu_add_item(GntMenu *menu, Gn
  *
  * Return the GntMenuItem with the given ID.
  *
- * Returns:  The menuitem with the given ID, or %NULL.
+ * Returns: (transfer none): The menuitem with the given ID, or %NULL.
  *
  * Since: 2.3.0
  */
diff --git a/finch/libgnt/gntmenuitem.h b/finch/libgnt/gntmenuitem.h
--- a/finch/libgnt/gntmenuitem.h
+++ b/finch/libgnt/gntmenuitem.h
@@ -108,9 +108,9 @@ GntMenuItem * gnt_menuitem_new(const cha
 
 /**
  * gnt_menuitem_set_callback:
- * @item:       The menuitem.
- * @callback:   The callback function.
- * @data:       Data to send to the callback function.
+ * @item:     The menuitem.
+ * @callback: (scope call): The callback function.
+ * @data:     Data to send to the callback function.
  *
  * Set a callback function for a menuitem.
  */
@@ -131,7 +131,7 @@ void gnt_menuitem_set_submenu(GntMenuIte
  *
  * Get the submenu for a menuitem.
  *
- * Returns:  The submenu, or %NULL.
+ * Returns: (transfer none): The submenu, or %NULL.
  *
  * Since: 2.3.0
  */
diff --git a/finch/libgnt/gntstyle.h b/finch/libgnt/gntstyle.h
--- a/finch/libgnt/gntstyle.h
+++ b/finch/libgnt/gntstyle.h
@@ -76,14 +76,15 @@ char *gnt_style_get_from_name(const char
 
 /**
  * gnt_style_get_string_list:
- * @group:   The name of the group in the keyfile. If %NULL, the prgname
- *                will be used first, if available. Otherwise, "general" will be used.
- * @key:     The key
- * @length:  Return location for the number of strings returned, or NULL
+ * @group:  The name of the group in the keyfile. If %NULL, the prgname
+ *          will be used first, if available. Otherwise, "general" will be used.
+ * @key:    The key
+ * @length: Return location for the number of strings returned, or NULL
  *
  * Get the value of a preference in ~/.gntrc.
  *
- * Returns:        NULL terminated string array. The array should be freed with g_strfreev().
+ * Returns: (transfer full): %NULL terminated string array. The array should be
+ *          freed with g_strfreev().
  *
  * Since: 2.4.0
  */
diff --git a/finch/libgnt/gnttree.h b/finch/libgnt/gnttree.h
--- a/finch/libgnt/gnttree.h
+++ b/finch/libgnt/gnttree.h
@@ -206,7 +206,7 @@ GntTreeRow * gnt_tree_add_row_last(GntTr
  *
  * Get the key for the selected row.
  *
- * Returns:   The key for the selected row
+ * Returns: (transfer none): The key for the selected row
  */
 gpointer gnt_tree_get_selection_data(GntTree *tree);
 
@@ -226,17 +226,21 @@ char * gnt_tree_get_selection_text(GntTr
  * gnt_tree_get_row_text_list:
  * @tree:  The tree
  * @key:   A key corresponding to the row in question. If key
- *              is %NULL, the text list for the selected row will
- *              be returned.
+ *         is %NULL, the text list for the selected row will
+ *         be returned.
  *
  * Get a list of text for a row.
  *
  * See gnt_tree_get_selection_text_list(), gnt_tree_get_selection_text().
  *
  * Returns: A list of texts of a row. The list and its data should be
  *         freed by the caller. The caller should make sure that if
  *         any column of the tree contains binary data, it's not freed.
  */
+/* TODO This leaks when used from introspection. The transfer mode for the
+        return type here should be 'full', but that would free binary data as
+        well. */
 GList * gnt_tree_get_row_text_list(GntTree *tree, gpointer key);
 
 /**
@@ -246,7 +250,7 @@ GList * gnt_tree_get_row_text_list(GntTr
  *
  * Get the key of a row.
  *
- * Returns: The key of the row.
+ * Returns: (transfer none): The key of the row.
  *
  * Since: 2.8.0 (gnt), 2.7.2 (pidgin)
  */
@@ -312,11 +316,14 @@ GntTreeRow * gnt_tree_row_get_parent(Gnt
  *
  * See gnt_tree_get_row_text_list(), gnt_tree_get_selection_text().
  *
  * Returns: A list of texts of the currently selected row. The list
  *         and its data should be freed by the caller. The caller
  *         should make sure that if any column of the tree contains
  *         binary data, it's not freed.
  */
+/* TODO This leaks when used from introspection. The transfer mode for the
+        return type here should be 'full', but that would free binary data as
@@ -226,17 +226,21 @@ char * gnt_tree_get_selection_text(GntTr
  * See gnt_tree_get_selection_text_list(), gnt_tree_get_selection_text().
  *
- * Returns: A list of texts of a row. The list and its data should be
- *         freed by the caller. The caller should make sure that if
- *         any column of the tree contains binary data, it's not freed.
+ * Returns: (transfer container) (element-type utf8): A list of texts of a row.
+ *          The list and its data should be freed by the caller. The caller
+ *          should make sure that if any column of the tree contains binary
+ *          data, it's not freed.
  */
@@ -312,11 +316,14 @@ GntTreeRow * gnt_tree_row_get_parent(Gnt
  * See gnt_tree_get_row_text_list(), gnt_tree_get_selection_text().
  *
- * Returns: A list of texts of the currently selected row. The list
- *         and its data should be freed by the caller. The caller
- *         should make sure that if any column of the tree contains
- *         binary data, it's not freed.
+ * Returns: (transfer container) (element-type utf8): A list of texts of the
+ *          currently selected row. The list and its data should be freed by
+ *          the caller. The caller should make sure that if any column of the
+ *          tree contains binary data, it's not freed.
  */



More information about the Commits mailing list